#The function allows to unpack lists of multiple lines#

def unpackList(list_to_work):
	
	for each_item in list_to_work:
		
		if(isinstance(each_item, list)):
			unpackList(each_item)
		else:
			print (each_item)
			
	




from distutils.core import setup
setup(
 name = "unpackList",
 version = '1.0.0',
 py_modules = ['unpackList'],
 author = 'Santhosh',
 author_email = 'dummy@zombie.com',
 url = 'http://www.google.com',
 description = "This unpacks the list passed to it",
)
